==> 0.6.1.tar.gz: example/bin/main.dart <==
library ac_dart.example.example_addon;

import 'package:atlassian_connect_shelf/acdart_app.dart';
import 'config.dart';
import 'dart:async';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:http_server/http_server.dart';
import 'package:logging/logging.dart';


final Logger _log = new Logger('ac_dart.example.app');

void main() {
  final app = acdart(config);
  
  // add standard handlers for installation and descriptor
  app.router..addInstallationRoute()
            ..addDescriptorTemplateRoute();
  
  // define a child route for all routes that will be authenticated via addon session token
  app.router.child('/service',
      middleware: app.addonSessionAuthenticator)
      ..get('/issue/{issueKey}', _fetchJiraIssue);
//      ..put('/issue/{issueKey}', _updateJiraIssue);
      
  // define a child route for all routes that will be authenticated via Atlassian Host token
  app.router.child('/ui',
      middleware: app.atlassianHostAuthenticator)
      ..get('/exampleUI.html',
          app.moustacheFile('ui/exampleUI.html', includeExtraParams: true))
      ..get('/static', app.createStaticHandler(fileSystemPath: '../static'));
  
  // start your engines
  app.start();
}

Future<Map> _fetchJiraIssue(String issueKey, AcHostHttpClient httpClient) {
  _log.fine('fetching jira issue $issueKey');

  final jiraResponse =
      httpClient.get('rest/api/2/issue/$issueKey', signRequest: true)
        .then((req) => req.close());

  return jiraResponse
      .then(HttpBodyHandler.processResponse)
      .then((body) => body.body);
}

==> 0.7.0.tar.gz: example/bin/main.dart <==
library ac_dart.example.example_addon;

import 'package:atlassian_connect_shelf/acdart_app.dart';
import 'config.dart';
import 'dart:async';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:http_server/http_server.dart';
import 'package:logging/logging.dart';
import 'descriptor.dart';

final Logger _log = new Logger('ac_dart.example.app');

void main() {
  final app = acdart(config);
  
  // add standard handlers for installation and descriptor
  app.router..addInstallationRoute()
//            ..addDescriptorTemplateRoute();
            ..addDescriptorRoute(createAddon(app.config.addonHost));
  
  // define a child route for all routes that will be authenticated via addon session token
  app.router.child('/service',
      middleware: app.addonSessionAuthenticator)
      ..get('/issue/{issueKey}', _fetchJiraIssue);
//      ..put('/issue/{issueKey}', _updateJiraIssue);
      
  // define a child route for all routes that will be authenticated via Atlassian Host token
  app.router.child('/ui',
      middleware: app.atlassianHostAuthenticator)
      ..get('/exampleUI.html',
          app.moustacheFile('ui/exampleUI.html', includeExtraParams: true))
      ..get('/static', app.createStaticHandler(fileSystemPath: '../static'));
  
  // start your engines
  app.start();
}

Future<Map> _fetchJiraIssue(String issueKey, AcHostHttpClient httpClient) {
  _log.fine('fetching jira issue $issueKey');

  final jiraResponse =
      httpClient.get('rest/api/2/issue/$issueKey', signRequest: true)
        .then((req) => req.close());

  return jiraResponse
      .then(HttpBodyHandler.processResponse)
      .then((body) => body.body);
}
